# Changelog

## 0.5.3

* Parameters no longer missing in package (fix MANIFEST.in)

## 0.5.2

* Migrate survey_scenario to core v20

## 0.5.1

* Add some links to execute notebooks on [mybinder](https://mybinder.org/)

## 0.5.0

* Migrate to core v20

## 0.4.3

* Migrate to core v14.1.2

## 0.4.2

* Use a core version that works with the api

## 0.4.1

* Fix OpenFisca-Survey-Manager dependency

## 0.4.0

* Add `SurveyScenario` class
* Add OpenFisca-Survey-Manager optional dependancy

## 0.3.1

* Clarify setup.cfg

## 0.3.0

* Add parameters.xml in MANIFEST.in

## 0.0.0

* Unreleased
